<?php

namespace Drupal\tmgmt_extension_suit\Form;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\tmgmt_extension_suit\ExtendedTranslatorPluginInterface;

/**
 * Provides a confirmation form for sending multiple content entities.
 */
class UploadTmgmtActionApproveForm extends BaseTmgmtActionApproveForm {

  /**
   * Temp storage name we are saving entity_ids to.
   *
   * @var string
   */
  protected $tempStorageName = 'tmgmt_extension_suit_tmgmt_job_operations_upload';


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tmgmt_extension_suit_send_multiple_confirm';
  }

  /**
   * Processes the sending batch.
   *
   * @param array $data
   *   Keyed array of data to send.
   * @param array $context
   *   The batch context.
   */
  public static function processBatch($data, &$context) {
    if (!isset($context['results']['errors'])) {
      $context['results']['errors'] = [];
      $context['results']['count'] = 0;
    }

    $entity_type_id = $data['entity_type'];
    $entity_id = $data['entity_id'];

    $job = \Drupal::entityTypeManager()->getStorage($entity_type_id)
             ->loadMultiple([$entity_id]);
    $job = reset($job);


    if (!$job) {
      $context['results']['errors'][] = t('Entity @entity_type:@entity_id not found', [
        '@entity_type' => $entity_type_id,
        '@entity_id' => $entity_id,
      ]);
    }
    elseif ($translator = $job->getTranslator()) {
      $translator_plugin = $job->getTranslatorPlugin();

      if ($translator_plugin instanceof ExtendedTranslatorPluginInterface) {
        \Drupal::getContainer()
          ->get('logger.channel.tmgmt_extension_suit')
          ->info(t('File upload triggered (view action). Job id: @job_id, file name: @name.', [
            '@name' => $translator_plugin->getFileName($job),
            '@job_id' => $job->id(),
          ]));
      }

      $translator->getPlugin()->requestTranslation($job);

      $context['results']['count']++;
      $context['message'] = new FormattableMarkup('Processed %name.', [
        '%name' => $job->label(),
      ]);
    }
    else {
      $context['message'] = new FormattableMarkup('Skipped %name.', [
        '%name' => $entity_type_id, //$entity->label(),
      ]);
    }
  }
}
